@@ -1,8 +1,7 @@
 import os
 import re
-from dataclasses import dataclass, field
 from pathlib import Path
-from unittest.mock import MagicMock, patch
+from unittest.mock import patch
 
 import pytest
 import zstandard as zstd
@@ -17,11 +16,7 @@ from datasets.utils.file_utils import (
     cached_path,
     fsspec_get,
     fsspec_head,
-    ftp_get,
-    ftp_head,
     get_from_cache,
-    http_get,
-    http_head,
     xdirname,
     xexists,
     xgetsize,
@@ -79,87 +74,6 @@ def tmpfs_file(tmpfs):
     return FILE_PATH
 
 
-@pytest.mark.parametrize(
-    "protocol, download_config_storage_options, expected_fsspec_called",
-    [
-        ("hf", {}, True),
-        ("s3", {"s3": {"anon": True}}, True),
-        # HTTP calls fsspec only if passed HTTP download_config.storage_options:
-        ("https", {"https": {"block_size": "omit"}}, True),
-        ("https", {}, False),
-    ],
-)
-def test_cached_path_calls_fsspec_for_protocols(
-    protocol, download_config_storage_options, expected_fsspec_called, monkeypatch, tmp_path
-):
-    # GH-6598: Test no TypeError: __init__() got an unexpected keyword argument 'hf'
-    # fsspec_head/get:
-    mock_fsspec_head = MagicMock(return_value={})
-    mock_fsspec_get = MagicMock(return_value=None)
-    monkeypatch.setattr("datasets.utils.file_utils.fsspec_head", mock_fsspec_head)
-    monkeypatch.setattr("datasets.utils.file_utils.fsspec_get", mock_fsspec_get)
-
-    # http_head_get:
-    @dataclass
-    class Response:
-        status_code: int
-        headers: dict = field(default_factory=dict)
-        cookies: dict = field(default_factory=dict)
-
-    mock_http_head = MagicMock(return_value=Response(status_code=200))
-    mock_http_get = MagicMock(return_value=None)
-    monkeypatch.setattr("datasets.utils.file_utils.http_head", mock_http_head)
-    monkeypatch.setattr("datasets.utils.file_utils.http_get", mock_http_get)
-    # Test:
-    cache_dir = tmp_path / "cache"
-    download_config = DownloadConfig(cache_dir=cache_dir, storage_options=download_config_storage_options)
-    urls = {
-        "hf": "hf://datasets/org-name/ds-name@main/filename.ext",
-        "https": "https://doamin.org/filename.ext",
-        "s3": "s3://bucket-name/filename.ext",
-    }
-    url = urls[protocol]
-    _ = cached_path(url, download_config=download_config)
-    if expected_fsspec_called:
-        for mock in [mock_fsspec_head, mock_fsspec_get]:
-            assert mock.called
-            assert mock.call_count == 1
-            assert mock.call_args.args[0] == url
-            assert list(mock.call_args.kwargs["storage_options"].keys()) == [protocol]
-        for mock in [mock_http_head, mock_http_get]:
-            assert not mock.called
-    else:
-        for mock in [mock_fsspec_head, mock_fsspec_get]:
-            assert not mock.called
-        for mock in [mock_http_head, mock_http_get]:
-            assert mock.called
-            assert mock.call_count == 1
-            assert mock.call_args.args[0] == url
-
-
-@pytest.mark.parametrize(
-    "download_config_storage_options, expected_storage_options_passed_to_get_from_catch",
-    [
-        ({}, {}),  # No DownloadConfig.storage_options
-        ({"https": {"block_size": "omit"}}, {"https": {"client_kwargs": {"trust_env": True}, "block_size": "omit"}}),
-    ],
-)
-def test_cached_path_passes_http_storage_options_to_get_from_cache_only_if_present_in_download_config(
-    download_config_storage_options, expected_storage_options_passed_to_get_from_catch, monkeypatch, tmp_path
-):
-    # Test cached_path passes HTTP storage_options to get_from_cache only if passed HTTP download_config.storage_options
-    mock_get_from_catch = MagicMock(return_value=None)
-    monkeypatch.setattr("datasets.utils.file_utils.get_from_cache", mock_get_from_catch)
-    url = "https://domain.org/data.txt"
-    cache_dir = tmp_path / "cache"
-    download_config = DownloadConfig(cache_dir=cache_dir, storage_options=download_config_storage_options)
-    _ = cached_path(url, download_config=download_config)
-    assert mock_get_from_catch.called
-    assert mock_get_from_catch.call_count == 1
-    assert mock_get_from_catch.call_args.args[0] == url
-    assert mock_get_from_catch.call_args.kwargs["storage_options"] == expected_storage_options_passed_to_get_from_catch
-
-
 @pytest.mark.parametrize("compression_format", ["gzip", "xz", "zstd"])
 def test_cached_path_extract(compression_format, gz_file, xz_file, zstd_path, tmp_path, text_file):
     input_paths = {"gzip": gz_file, "xz": xz_file, "zstd": zstd_path}
@@ -232,24 +146,6 @@ def test_cached_path_offline():
         cached_path("https://huggingface.co")
 
 
-@patch("datasets.config.HF_HUB_OFFLINE", True)
-def test_http_offline(tmp_path_factory):
-    filename = tmp_path_factory.mktemp("data") / "file.html"
-    with pytest.raises(OfflineModeIsEnabled):
-        http_get("https://huggingface.co", temp_file=filename)
-    with pytest.raises(OfflineModeIsEnabled):
-        http_head("https://huggingface.co")
-
-
-@patch("datasets.config.HF_HUB_OFFLINE", True)
-def test_ftp_offline(tmp_path_factory):
-    filename = tmp_path_factory.mktemp("data") / "file.html"
-    with pytest.raises(OfflineModeIsEnabled):
-        ftp_get("ftp://huggingface.co", temp_file=filename)
-    with pytest.raises(OfflineModeIsEnabled):
-        ftp_head("ftp://huggingface.co")
-
-
 @patch("datasets.config.HF_HUB_OFFLINE", True)
 def test_fsspec_offline(tmp_path_factory):
     filename = tmp_path_factory.mktemp("data") / "file.html"
