@@ -29,14 +29,11 @@ from datasets.features import Features, Image, Value
 from datasets.iterable_dataset import IterableDataset
 from datasets.load import (
     CachedDatasetModuleFactory,
-    CachedMetricModuleFactory,
-    GithubMetricModuleFactory,
     HubDatasetModuleFactoryWithoutScript,
     HubDatasetModuleFactoryWithParquetExport,
     HubDatasetModuleFactoryWithScript,
     LocalDatasetModuleFactoryWithoutScript,
     LocalDatasetModuleFactoryWithScript,
-    LocalMetricModuleFactory,
     PackagedDatasetModuleFactory,
     infer_module_for_data_files_list,
     infer_module_for_data_files_list_in_archives,
@@ -104,23 +101,6 @@ SAMPLE_DATASET_TWO_CONFIG_IN_METADATA_WITH_DEFAULT = (
 SAMPLE_DATASET_CAPITAL_LETTERS_IN_NAME = "hf-internal-testing/DatasetWithCapitalLetters"
 
 
-METRIC_LOADING_SCRIPT_NAME = "__dummy_metric1__"
-
-METRIC_LOADING_SCRIPT_CODE = """
-import datasets
-from datasets import MetricInfo, Features, Value
-
-
-class __DummyMetric1__(datasets.Metric):
-
-    def _info(self):
-        return MetricInfo(features=Features({"predictions": Value("int"), "references": Value("int")}))
-
-    def _compute(self, predictions, references):
-        return {"__dummy_metric1__": sum(int(p == r) for p, r in zip(predictions, references))}
-"""
-
-
 @pytest.fixture
 def data_dir(tmp_path):
     data_dir = tmp_path / "data_dir"
@@ -328,17 +308,6 @@ def dataset_loading_script_dir_readonly(tmp_path):
     return dataset_loading_script_dir
 
 
-@pytest.fixture
-def metric_loading_script_dir(tmp_path):
-    script_name = METRIC_LOADING_SCRIPT_NAME
-    script_dir = tmp_path / script_name
-    script_dir.mkdir()
-    script_path = script_dir / f"{script_name}.py"
-    with open(script_path, "w") as f:
-        f.write(METRIC_LOADING_SCRIPT_CODE)
-    return str(script_dir)
-
-
 @pytest.mark.parametrize(
     "data_files, expected_module, expected_builder_kwargs",
     [
@@ -397,7 +366,6 @@ class ModuleFactoryTest(TestCase):
         data_dir_with_two_config_in_metadata,
         sub_data_dirs,
         dataset_loading_script_dir,
-        metric_loading_script_dir,
     ):
         self._jsonl_path = jsonl_path
         self._data_dir = data_dir
@@ -408,7 +376,6 @@ class ModuleFactoryTest(TestCase):
         self._data_dir2 = sub_data_dirs[0]
         self._sub_data_dir = sub_data_dirs[1]
         self._dataset_loading_script_dir = dataset_loading_script_dir
-        self._metric_loading_script_dir = metric_loading_script_dir
 
     def setUp(self):
         self.hf_modules_cache = tempfile.mkdtemp()
@@ -448,42 +415,6 @@ class ModuleFactoryTest(TestCase):
         assert importlib.import_module(module_factory_result.module_path) is not None
         assert module_factory_result.builder_kwargs["base_path"].startswith(config.HF_ENDPOINT)
 
-    def test_GithubMetricModuleFactory_with_internal_import(self):
-        # "squad_v2" requires additional imports (internal)
-        factory = GithubMetricModuleFactory(
-            "squad_v2",
-            revision="2.21",
-            download_config=self.download_config,
-            dynamic_modules_path=self.dynamic_modules_path,
-            trust_remote_code=True,
-        )
-        module_factory_result = factory.get_module()
-        assert importlib.import_module(module_factory_result.module_path) is not None
-
-    @pytest.mark.filterwarnings("ignore:GithubMetricModuleFactory is deprecated:FutureWarning")
-    def test_GithubMetricModuleFactory_with_external_import(self):
-        # "bleu" requires additional imports (external from github)
-        factory = GithubMetricModuleFactory(
-            "bleu",
-            revision="2.21",
-            download_config=self.download_config,
-            dynamic_modules_path=self.dynamic_modules_path,
-            trust_remote_code=True,
-        )
-        module_factory_result = factory.get_module()
-        assert importlib.import_module(module_factory_result.module_path) is not None
-
-    def test_LocalMetricModuleFactory(self):
-        path = os.path.join(self._metric_loading_script_dir, f"{METRIC_LOADING_SCRIPT_NAME}.py")
-        factory = LocalMetricModuleFactory(
-            path,
-            download_config=self.download_config,
-            dynamic_modules_path=self.dynamic_modules_path,
-            trust_remote_code=True,
-        )
-        module_factory_result = factory.get_module()
-        assert importlib.import_module(module_factory_result.module_path) is not None
-
     def test_LocalDatasetModuleFactoryWithScript(self):
         path = os.path.join(self._dataset_loading_script_dir, f"{DATASET_LOADING_SCRIPT_NAME}.py")
         factory = LocalDatasetModuleFactoryWithScript(
@@ -859,10 +790,10 @@ class ModuleFactoryTest(TestCase):
         )
         assert module_factory_result.builder_configs_parameters.builder_configs[0].data_files == {
             "train": [
-                "hf://datasets/hf-internal-testing/dataset_with_script@0c97cd1168f31e683059ddcf0703e3f45d9007c4/default/train/0000.parquet"
+                "hf://datasets/hf-internal-testing/dataset_with_script@3d8a0e457ddb581301fb13f60d38906c9cdcaf1c/default/train/0000.parquet"
             ],
             "validation": [
-                "hf://datasets/hf-internal-testing/dataset_with_script@0c97cd1168f31e683059ddcf0703e3f45d9007c4/default/validation/0000.parquet"
+                "hf://datasets/hf-internal-testing/dataset_with_script@3d8a0e457ddb581301fb13f60d38906c9cdcaf1c/default/validation/0000.parquet"
             ],
         }
 
@@ -871,7 +802,7 @@ class ModuleFactoryTest(TestCase):
         factory = HubDatasetModuleFactoryWithParquetExport(
             SAMPLE_DATASET_IDENTIFIER,
             download_config=self.download_config,
-            revision="1a21ac5846fc3f36ad5f128740c58932d3d7806f",
+            revision="0e1cee81e718feadf49560b287c4eb669c2efb1a",
         )
         factory.get_module()
         factory = HubDatasetModuleFactoryWithParquetExport(
@@ -913,38 +844,15 @@ class ModuleFactoryTest(TestCase):
                 module_factory_result = factory.get_module()
                 assert importlib.import_module(module_factory_result.module_path) is not None
 
-    @pytest.mark.filterwarnings("ignore:LocalMetricModuleFactory is deprecated:FutureWarning")
-    @pytest.mark.filterwarnings("ignore:CachedMetricModuleFactory is deprecated:FutureWarning")
-    def test_CachedMetricModuleFactory(self):
-        path = os.path.join(self._metric_loading_script_dir, f"{METRIC_LOADING_SCRIPT_NAME}.py")
-        factory = LocalMetricModuleFactory(
-            path,
-            download_config=self.download_config,
-            dynamic_modules_path=self.dynamic_modules_path,
-            trust_remote_code=True,
-        )
-        module_factory_result = factory.get_module()
-        for offline_mode in OfflineSimulationMode:
-            with offline(offline_mode):
-                factory = CachedMetricModuleFactory(
-                    METRIC_LOADING_SCRIPT_NAME,
-                    dynamic_modules_path=self.dynamic_modules_path,
-                )
-                module_factory_result = factory.get_module()
-                assert importlib.import_module(module_factory_result.module_path) is not None
-
 
 @pytest.mark.parametrize(
     "factory_class",
     [
         CachedDatasetModuleFactory,
-        CachedMetricModuleFactory,
-        GithubMetricModuleFactory,
         HubDatasetModuleFactoryWithoutScript,
         HubDatasetModuleFactoryWithScript,
         LocalDatasetModuleFactoryWithoutScript,
         LocalDatasetModuleFactoryWithScript,
-        LocalMetricModuleFactory,
         PackagedDatasetModuleFactory,
     ],
 )
@@ -1764,7 +1672,7 @@ def test_load_dataset_distributed(tmp_path, csv_path):
 
 def distributed_load_dataset_with_script(args):
     data_name, tmp_dir, download_mode = args
-    dataset = load_dataset(data_name, cache_dir=tmp_dir, download_mode=download_mode)
+    dataset = load_dataset(data_name, cache_dir=tmp_dir, download_mode=download_mode, trust_remote_code=True)
     return dataset
 
 
